@@ -126,7 +126,7 @@ class Client():
             return str(outp)
 
         try:
-            return _recv()
+            return _recv(), None
         except ConnectionResetError as e:
             return 500, e
         except socket.timeout as e:
